package commands

func init() {
// THIS FILE IS GENERATED, DO NOT EDIT
// Use 'go generate ./commands' to update
ManPages["checkout"] = `
git lfs checkout <filespec>...

Try to ensure that the working copy contains file content for Git LFS objects
for the current ref, if the object data is available. Does not download any
content, see git lfs fetch for that. 

Checkout scans the current ref for all LFS objects that would be required, then
where a file is either missing in the working copy, or contains placeholder
pointer content with the same SHA, the real file content is written, provided
we have it in the local store. Modified files are never overwritten.

Filespecs can be provided as arguments to restrict the files which are updated.

Examples
--------

* Checkout all files that are missing or placeholders
  
  git lfs checkout
  
* Checkout a specific couple of files
  
  git lfs checkout path/to/file1.png path/to.file2.png
  
`
ManPages["clean"] = `
git lfs clean <path>

Read the contents of a large file from standard input, and write a Git
LFS pointer file for that file to standard output.

Clean is typically run by Git's clean filter, configured by the repository's
Git attributes.

Clean is not part of the user-facing Git plumbing commands. To preview the
pointer of a large file as it would be generated, see the git lfs pointer
command.

`
ManPages["clone"] = `
git lfs clone [git clone options] <repository> [<directory>]

Clone an LFS enabled Git repository more efficiently by disabling LFS during the
git clone, then performing a 'git lfs pull' directly afterwards.

'git lfs clone' also installs all of the repo-level hooks (.git/hooks) that LFS
requires to operate. If --separate-git-dir is given, the hooks will be
installed there.

This is faster than a regular 'git clone' because that will download LFS content
using the smudge filter, which is executed individually per file in the working
copy. This is relatively inefficient compared to the batch mode and parallel
downloads performed by 'git lfs pull'.

Options:

All options supported by 'git clone'

* -I <paths> --include=<paths>:
  See "Include and exclude"
  
* -X <paths> --exclude=<paths>:
  See "Include and exclude"
  
* --skip-repo:
  Skip installing repo-level hooks (.git/hooks) that LFS requires. Disabled by
  default.
  
Include and exclude
-------------------

You can configure Git LFS to only fetch objects to satisfy references in certain
paths of the repo, and/or to exclude certain paths of the repo, to reduce the
time you spend downloading things you do not use.

In lfsconfig, set lfs.fetchinclude and lfs.fetchexclude to comma-separated lists
of paths to include/exclude in the fetch (wildcard matching as per gitignore).
Only paths which are matched by fetchinclude and not matched by fetchexclude
will have objects fetched for them.

`
ManPages["config"] = `Configuration files
-------------------

git-lfs reads its configuration from a file called .lfsconfig at the root of
the repository. The .lfsconfig file uses the same format as .gitconfig.

Additionally, all settings can be overridden by values returned by git config -l.
This allows you to override settings like lfs.url in your local environment
without having to modify the .lfsconfig file.

Most options regarding git-lfs are contained in the [lfs] section, meaning
they are all named lfs.foo or similar, although occasionally an lfs option can
be scoped inside the configuration for a remote.


List of options
---------------

General settings
----------------

* lfs.url / remote.<remote>.lfsurl
  
  The url used to call the Git LFS remote API. Default blank (derive from clone
  URL).
  
* lfs.pushurl / remote.<remote>.lfspushurl
  
  The url used to call the Git LFS remote API when pushing. Default blank (derive
  from either LFS non-push urls or clone url).
  
* lfs.dialtimeout
  
  Sets the maximum time, in seconds, that the HTTP client will wait to initiate
  a connection. This does not include the time to send a request and wait for a
  response. Default: 30 seconds
  
* lfs.tlstimeout
  
  Sets the maximum time, in seconds, that the HTTP client will wait for a TLS
  handshake. Default: 30 seconds.
  
* lfs.activitytimeout / lfs.https://<host>.activitytimeout
  
  Sets the maximum time, in seconds, that the HTTP client will wait for the
  next tcp read or write. If < 1, no activity timeout is used at all.
  Default: 30 seconds
  
* lfs.keepalive
  
  Sets the maximum time, in seconds, for the HTTP client to maintain keepalive
  connections. Default: 30 minutes.
  
* core.askpass, GIT_ASKPASS
  
  Given as a program and its arguments, this is invoked when authentication is
  needed against the LFS API. The contents of stdout are interpreted as the
  password.
  
* lfs.cachecredentials
  
  Enables in-memory SSH and Git Credential caching for a single 'git lfs'
  command. Default: enabled.
  
* lfs.storage
  
  Allow override LFS storage directory. Non-absolute path is relativized to
  inside of Git repository directory (usually .git).
  
  Note: you should not run git lfs prune if you have different repositories
  sharing the same storage directory.
  
  Default: lfs in Git repository directory (usually .git/lfs).
  
Transfer 
---------

  These settings control how the upload and download of LFS content occurs.

* lfs.concurrenttransfers
  
  The number of concurrent uploads/downloads. Default 8.
  
* lfs.basictransfersonly
  
  If set to true, only basic HTTP upload/download transfers will be used,
  ignoring any more advanced transfers that the client/server may support.
  This is primarily to work around bugs or incompatibilities.
  
  The git-lfs client supports basic HTTP downloads, resumable HTTP downloads
  (using Range headers), and resumable uploads via tus.io protocol. Custom
  transfer methods can be added via lfs.customtransfer (see next section).
  However setting this value to true limits the client to simple HTTP.
  
* lfs.tustransfers
  
  If set to true, this enables resumable uploads of LFS objects through the
  tus.io API. Once this feature is finalized, this setting will be removed,
  and tus.io uploads will be available for all clients.
  
* lfs.standalonetransferagent
  
  Allows the specified custom transfer agent to be used directly
  for transferring files, without asking the server how the transfers
  should be made. The custom transfer agent has to be defined in a
  lfs.customtransfer.<name> settings group.
  
* lfs.customtransfer.<name>.path
  
  lfs.customtransfer.<name> is a settings group which defines a custom
  transfer hook which allows you to upload/download via an intermediate process,
  using any mechanism you like (rather than just HTTP). path should point to
  the process you wish to invoke. The protocol between the git-lfs client and
  the custom transfer process is documented at
  https://github.com/git-lfs/git-lfs/blob/master/docs/custom-transfers.md
  
  <name> must be a unique identifier that the LFS server understands. When
  calling the LFS API the client will include a list of supported transfer
  types. If the server also supports this named transfer type, it will select it
  and actions returned from the API will be in relation to that transfer type
  (may not be traditional URLs for example). Only if the server accepts <name>
  as a transfer it supports will this custom transfer process be invoked.
  
* lfs.customtransfer.<name>.args
  
  If the custom transfer process requires any arguments, these can be provided
  here.
  
* lfs.customtransfer.<name>.concurrent
  
  If true (the default), git-lfs will invoke the custom transfer process
  multiple times in parallel, according to lfs.concurrenttransfers, splitting
  the transfer workload between the processes.
  
* lfs.customtransfer.<name>.direction
  
  Specifies which direction the custom transfer process supports, either
  "download", "upload", or "both". The default if unspecified is "both".
  
* lfs.transfer.maxretries
  
  Specifies how many retries LFS will attempt per OID before marking the
  transfer as failed. Must be an integer which is at least one. If the value is
  not an integer, is less than one, or is not given, a value of eight will be
  used instead.
  
* lfs.transfer.maxverifies
  
  Specifies how many verification requests LFS will attempt per OID before
  marking the transfer as failed, if the object has a verification action
  associated with it. Must be an integer which is at least one. If the value is
  not an integer, is less than one, or is not given, a default value of three
  will be used instead.
  
Push settings
-------------

* lfs.allowincompletepush
  
  When pushing, allow objects to be missing from the local cache without halting
  a Git push. Default: true.
  
Fetch settings
--------------

* lfs.fetchinclude
  
  When fetching, only download objects which match any entry on this
  comma-separated list of paths/filenames. Wildcard matching is as per
  git  ignore. See git lfs fetch for examples.
  
* lfs.fetchexclude
  
  When fetching, do not download objects which match any item on this
  comma-separated list of paths/filenames. Wildcard matching is as per
  git  ignore. See git lfs fetch for examples.
  
* lfs.fetchrecentrefsdays
  
  If non-zero, fetches refs which have commits within N days of the current
  date. Only local refs are included unless lfs.fetchrecentremoterefs is true.
  Also used as a basis for pruning old files.
  The default is 7 days.
  
* lfs.fetchrecentremoterefs
  
  If true, fetches remote refs (for the remote you're fetching) as well as local
  refs in the recent window. This is useful to fetch objects for remote branches
  you might want to check out later. The default is true; if you set this to
  false, fetching for those branches will only occur when you either check them
  out (losing the advantage of fetch --recent), or create a tracking local
  branch separately then fetch again.
  
* lfs.fetchrecentcommitsdays
  
  In addition to fetching at refs, also fetches previous changes made within N
  days of the latest commit on the ref. This is useful if you're often reviewing
  recent changes.   Also used as a basis for pruning old files.
  The default is 0 (no previous changes).
  
* lfs.fetchrecentalways
  
  Always operate as if --recent was included in a git lfs fetch call. Default
  false.
  
Prune settings
--------------

* lfs.pruneoffsetdays
  
  The number of days added to the lfs.fetchrecent* settings to determine what
  can be pruned. Default is 3 days, i.e. that anything fetched at the very
  oldest edge of the 'recent window' is eligible for pruning 3 days later.
  
* lfs.pruneremotetocheck
  
  Set the remote that LFS files must have been pushed to in order for them to
  be considered eligible for local pruning. Also the remote which is called if
  --verify-remote is enabled.
  
* lfs.pruneverifyremotealways
  
  Always run git lfs prune as if --verify-remote was provided.
  
Extensions
----------

* lfs.extension.<name>.<setting>
  
  Git LFS extensions enable the manipulation of files streams during smudge and
  clean. name groups the settings for a single extension, and the settings
  are:
  * clean The command which runs when files are added to the index
  * smudge The command which runs when files are written to the working copy
  * priority The order of this extension compared to others
  
Other settings
--------------

* lfs.<url>.access
  
  Note: this setting is normally set by LFS itself on receiving a 401 response
  (authentication required), you don't normally need to set it manually.
  
  If set to "basic" then credentials will be requested before making batch
  requests to this url, otherwise a public request will initially be attempted.
  
* lfs.<url>.locksverify
  
  Determines whether locks are checked before Git pushes. This prevents you from
  pushing changes to files that other users have locked. The Git LFS pre-push
  hook varies its behavior based on the value of this config key.
  
  * null - In the absence of a value, Git LFS will attempt the call, and warn
  if it returns an error. If the response is valid, Git LFS will set the value
  to true, and will halt the push if the user attempts to update a file locked
  by another user. If the server returns a 501 Not Implemented response, Git
  LFS will set the value to false.
  * true - Git LFS will attempt to verify locks, halting the Git push if there
  are any server issues, or if the user attempts to update a file locked by
  another user.
  * false - Git LFS will completely skip the lock check in the pre-push hook.
  You should set this if you're not using File Locking, or your Git server
  verifies locked files on pushes automatically.
  
  Supports URL config lookup as described in:
  https://git-scm.com/docs/git-config#git-config-httplturlgt. To set this value
  per-host: git config --global lfs.https://github.com/.locksverify [true|false].
  
* lfs.skipdownloaderrors
  
  Causes Git LFS not to abort the smudge filter when a download error is
  encountered, which allows actions such as checkout to work when you are unable
  to download the LFS content. LFS files which could not download will contain
  pointer content instead.
  
  Note that this will result in git commands which call the smudge filter to
  report success even in cases when LFS downloads fail, which may affect
  scripts.
  
  You can also set the environment variable GIT_LFS_SKIP_DOWNLOAD_ERRORS=1 to
  get the same effect.
  
* GIT_LFS_PROGRESS
  
  This environment variable causes Git LFS to emit progress updates to an
  absolute file-path on disk when cleaning, smudging, or fetching.
  
  Progress is reported periodically in the form of a new line being appended to
  the end of the file. Each new line will take the following format:
  
  <direction> <current>/<total files> <downloaded>/<total> <name>
  
  Each field is described below:
  * direction: The direction of transfer, either "checkout", "download", or
    "upload".
  * current The index of the currently transferring file.
  * total files The estimated count of all files to be transferred.
  * downloaded The number of bytes already downloaded.
  * total The entire size of the file, in bytes.
  * name The name of the file.
  
* GIT_LFS_SET_LOCKABLE_READONLY
  lfs.setlockablereadonly
  
  These settings, the first an environment variable and the second a gitconfig
  setting, control whether files marked as 'lockable' in git lfs track are
  made read-only in the working copy when not locked by the current user.
  The default is true; you can disable this behaviour and have all files
  writeable by setting either variable to 0, 'no' or 'false'.
  
Lfsconfig
---------

The .lfsconfig file in a repository is read and interpreted in the same format
as the file stored in .git/config. It allows a subset of keys to be used,
including and limited to:

- lfs.fetchexclude
- lfs.fetchinclude
- lfs.gitprotocol
- lfs.pushurl
- lfs.url
- lfs.extension.{name}.clean
- lfs.extension.{name}.smudge
- lfs.extension.{name}.priority
- remote.{name}.lfsurl
- remote.{name}.{*}.access

Examples
--------

*  Configure a custom LFS endpoint for your repository:
  
  git config -f .lfsconfig lfs.url https://lfs.example.com/foo/bar/info/lfs
  
`
ManPages["dedup"] = `
git lfs dedup

Deduplicates storage by re-creating working tree files as clones of the files in the Git LFS storage directory
using the operating system's copy-on-write file creation functionality.

If the operating system or file system don't support copy-on-write file creation, this command exits unsuccessfully.

This command will also exit without success if any Git LFS extensions are
configured, as these will typically be used to alter the file contents
before they are written to the Git LFS storage directory, and therefore the
working tree files should not be copy-on-write clones of the LFS object files.

`
ManPages["env"] = `
git lfs env

Display the current Git LFS environment.

`
ManPages["ext"] = `
git lfs ext list [<name>...]

Git LFS extensions enable the manipulation of files streams
during smudge and clean.

Examples
--------

* List details for all extensions
  
    git lfs ext
    git lfs ext list
  
* List details for the specified extensions
  
    git lfs ext list 'foo' 'bar'
  
`
ManPages["fetch"] = `
git lfs fetch [options] [<remote> [<ref>...]]

Download Git LFS objects at the given refs from the specified remote. See
"Default remote" and "Default refs" for what happens if you don't specify.

This does not update the working copy.

Options:

* -I <paths> --include=<paths>:
  Specify lfs.fetchinclude just for this invocation; see "Include and exclude"
  
* -X <paths> --exclude=<paths>:
  Specify lfs.fetchexclude just for this invocation; see "Include and exclude"
  
* --recent:
  Download objects referenced by recent branches & commits in addition to those
  that would otherwise be downloaded. See "Recent changes"
  
* --all:
  Download all objects referenced by any commit that is reachable; this is
  primarily for backup / migration purposes. Cannot be combined with --recent or
  --include/--exclude. Ignores any globally configured include and exclude paths
  to ensure that all objects are downloaded.
  
* --prune -p:
  Prune old and unreferenced objects after fetching, equivalent to running
  git lfs prune afterwards. See git lfs prune for more details.
  
Include and exclude
-------------------

You can configure Git LFS to only fetch objects to satisfy references in certain
paths of the repo, and/or to exclude certain paths of the repo, to reduce the
time you spend downloading things you do not use.

In gitconfig, set lfs.fetchinclude and lfs.fetchexclude to comma-separated lists
of paths to include/exclude in the fetch (pattern matching as per golang's
filepath.Match()).  Only paths which are matched by fetchinclude and not
matched by fetchexclude will have objects fetched for them.

Examples
--------

* git config lfs.fetchinclude "textures,images/foo*"
  
  This will only fetch objects referenced in paths in the textures folder, and
  files called foo* in the images folder
  
* git config lfs.fetchinclude "*.jpg,*.png,*.tga"
  
  Only fetch JPG/PNG/TGA files, wherever they are in the repository
  
* git config lfs.fetchexclude "media/reallybigfiles"
  
  Don't fetch any LFS objects referenced in the folder media/reallybigfiles, but
  fetch everything else
  
* git config lfs.fetchinclude "media"
  git config lfs.fetchexclude "media/excessive"
  
  Only fetch LFS objects in the 'media' folder, but exclude those in one of its
  subfolders.
  
Default remote
--------------

Without arguments, fetch downloads from the default remote.  The default remote
is the same as for git fetch, i.e. based on the remote branch you're tracking
first, or origin otherwise.

Default refs
------------

If no refs are given as arguments, the currently checked out ref is used. In
addition, if enabled, recently changed refs and commits are also
included. See "Recent changes" for details.

Recent changes
--------------

If the --recent option is specified, or if the gitconfig option
lfs.fetchrecentalways is true, then after the current ref (or those in the
arguments) is fetched, we also search for 'recent' changes to fetch
objects for, so that it's more convenient to checkout or diff those commits
without incurring further downloads.

What changes are considered 'recent' is based on a number of gitconfig options:

* lfs.fetchrecentrefsdays
  If non-zero, includes branches which have commits within N days of the current
  date. Only local refs are included unless lfs.fetchrecentremoterefs is true.
  The default is 7 days.
  
* lfs.fetchrecentremoterefs
  If true, fetches remote refs (for the remote you're fetching) as well as local
  refs in the recent window. This is useful to fetch objects for remote branches
  you might want to check out later. The default is true; if you set this to
  false, fetching for those branches will only occur when you either check them
  out (losing the advantage of fetch --recent), or create a tracking local
  branch separately then fetch again.
  
* lfs.fetchrecentcommitsdays
  In addition to fetching at branches, also fetches changes made within N
  days of the latest commit on the branch. This is useful if you're often
  reviewing recent changes. The default is 0 (no previous changes).
  
* lfs.fetchrecentalways
  Always operate as if --recent was provided on the command line.
  
  
Examples
--------

* Fetch the LFS objects for the current ref from default remote
  
  git lfs fetch
  
* Fetch the LFS objects for the current ref AND recent changes from default
  remote
  
  git lfs fetch --recent
  
* Fetch the LFS objects for the current ref from a secondary remote 'upstream'
  
  git lfs fetch upstream
  
* Fetch the LFS objects for a branch from origin
  
  git lfs fetch origin mybranch
  
* Fetch the LFS objects for 2 branches and a commit from origin
  
  git lfs fetch origin master mybranch e445b45c1c9c6282614f201b62778e4c0688b5c8
  
`
ManPages["filter-process"] = `
git lfs filter-process
git lfs filter-process --skip

Implement the Git process filter API, exchanging handshake messages and then
accepting and responding to requests to either clean or smudge a file.

filter-process is always run by Git's filter process, and is configured by the
repository's Git attributes.

The filter process uses Git's pkt-line protocol to communicate, and is
documented in detail in gitattributes(5).

Options:

Without any options, filter-process accepts and responds to requests normally.

* --skip:
    Skip automatic downloading of objects on clone or pull.
  
`
ManPages["fsck"] = `
git lfs fsck

Checks all GIT LFS files in the current HEAD for consistency.

Corrupted files are moved to ".git/lfs/bad".

`
ManPages["install"] = `
git lfs install [options]

Perform the following actions to ensure that Git LFS is setup properly:

* Set up the clean and smudge filters under the name "lfs" in the global Git
  config.
* Install a pre-push hook to run git lfs pre-push for the current repository,
  if run from inside one. If "core.hooksPath" is configured in any Git
  configuration (and supported, i.e., the installed Git version is at least
  2.9.0), then the pre-push hook will be installed to that directory instead.
  
Options:

Without any options, git lfs install will only setup the "lfs" smudge and clean
filters if they are not already set.

* --force:
    Sets the "lfs" smudge and clean filters, overwriting existing values.
* --local:
    Sets the "lfs" smudge and clean filters in the local repository's git
    config, instead of the global git config (~/.gitconfig).
* --manual:
    Print instructions for manually updating your hooks to include git-lfs
    functionality. Use this option if git lfs install fails because of existing
    hooks and you want to retain their functionality.
* --system:
    Sets the "lfs" smudge and clean filters in the system git config, e.g. /etc/gitconfig
    instead of the global git config (~/.gitconfig).
* --skip-smudge:
    Skips automatic downloading of objects on clone or pull. This requires a
    manual "git lfs pull" every time a new commit is checked out on your
    repository.
* --skip-repo:
    Skips setup of the local repo; use if you want to install the global lfs
    filters but not make changes to the current repo.
  
`
ManPages["lock"] = `
git lfs lock [options] <path>

Sets the given file path as "locked" against the Git LFS server, with the
intention of blocking attempts by other users to update the given path. Locking
a file requires the file to exist in the working copy.

Once locked, LFS will verify that Git pushes do not modify files locked by
other users. See the description of the lfs.<url>.locksverify config key in
git lfs config for details.

Options:

* -r <name> --remote=<name>:
  Specify the Git LFS server to use. Ignored if the lfs.url config key is set.
  
* --json:
  Writes lock info as JSON to STDOUT if the command exits successfully. Intended
  for interoperation with external tools. If the command returns with a non-zero
  exit code, plain text messages will be sent to STDERR.
  
`
ManPages["locks"] = `
git lfs locks [options]

Lists current locks from the Git LFS server.

Options:

* -r <name> --remote=<name>:
  Specify the Git LFS server to use. Ignored if the lfs.url config key is set.
  
* -i <id> --id=<id>:
  Specifies a lock by its ID. Returns a single result.
  
* -p <path> --path=<path>:
  Specifies a lock by its path. Returns a single result.
  
* --local:
  Lists only the locks cached locally. Skips a remote call.
  
* -l <num> --limit=<num>:
  Specifies number of results to return.
  
* --json:
  Writes lock info as JSON to STDOUT if the command exits successfully. Intended
  for interoperation with external tools. If the command returns with a non-zero
  exit code, plain text messages will be sent to STDERR.
  
`
ManPages["logs"] = `
git lfs logs
git lfs logs <file>
git lfs logs clear
git lfs logs boomtown

Display errors from the git-lfs command.  Any time it crashes, the details are
saved to ".git/lfs/logs".

Commands
--------

* clear:
    Clears all of the existing logged errors.
  
* boomtown:
    Triggers a dummy exception.
  
Options:

Without any options, git lfs logs simply shows the list of error logs.

* <file>:
    Shows the specified error log.  Use "last" to show the most recent error.
  
`
ManPages["ls-files"] = `
git lfs ls-files [<ref>]

Display paths of Git LFS files that are found in the tree at the given
reference.  If no reference is given, scan the currently checked-out branch.
An asterisk (*) after the OID indicates a LFS pointer, a minus (-) a full object.

Options:

* -l --long:
  Show the entire 64 character OID, instead of just first 10.
  
* -s --size:
  Show the size of the LFS object between parenthesis at the end of a line.
  
* -d --debug:
  Show as much information as possible about a LFS file. This is intended
  for manual inspection; the exact format may change at any time.
  
* -a --all:
  Inspects the full history of the repository, not the current HEAD (or other
  provided reference).
  
* --deleted:
  Shows the full history of the given reference, including objects that have
  been deleted.
  
* -I <paths> --include=<paths>:
  Include paths matching only these patterns; see "Fetch settings".
  
* -X <paths> --exclude=<paths>:
  Exclude paths matching any of these patterns; see "Fetch settings".
  
`
ManPages["migrate"] = `
git lfs migrate <mode> [options] "--" [branch ...]

Modes
-----

* info
    Show information about repository size.
  
* import
    Convert large Git objects to LFS pointers.
  
Options:

* -I <paths> --include=<paths>:
    See "Include and exclude".
  
* -X <paths> --exclude=<paths>:
    See "Include and exclude".
  
* --include-ref=<refname>:
    See [INCLUDE AND EXCLUDE (REFS)].
  
* --exclude-ref=<refname>:
    See [INCLUDE AND EXCLUDE (REFS)].
  
* --skip-fetch:
    Assumes that the known set of remote references is complete, and should not
    be refreshed when determining the set of "un-pushed" commits to migrate. Has
    no effect when combined with --include-ref or --exclude-ref.
  
* --everything:
    See [INCLUDE AND EXCLUDE (REFS)].
  
* [branch ...]:
    Migrate only the set of branches listed. If not given, git lfs migrate
    will migrate the currently checked out branch.
  
    References beginning with '^' will be excluded, whereas branches that do not
    begin with '^' will be included.
  
    If any of --include-ref or --exclude-ref are given, the checked out
    branch will not be appended, but branches given explicitly will be appended.
  
Info
----

The 'info' mode has these additional options:

* --above=<size>
    Only count files whose individual filesize is above the given size. 'size'
    may be specified as a number of bytes, or a number followed by a storage
    unit, e.g., "1b", "20 MB", "3 TiB", etc.
  
    If a set of files sharing a common extension has no files in that set whose
    individual size is above the given --above no files no entry for that set
    will be shown.
  
* --top=<n>
    Only include the top 'n' entries, ordered by how many total files match the
    given pathspec.
  
* --unit=<unit>
    Format the number of bytes in each entry as a quantity of the storage unit
    provided. Valid units include:
      * b, kib, mib, gib, tib, pib - for IEC storage units
      * b, kb, mb, gb, tb, pb - for SI storage units
  
    If a --unit is not specified, the largest unit that can fit the number of
    counted bytes as a whole number quantity is chosen.
  
Import
------

The 'import' mode migrates large objects present in the Git history to pointer
files tracked and stored with Git LFS. It supports all the core 'migrate'
options and these additional ones:

* --verbose
    Print the commit oid and filename of migrated files to STDOUT.
  
  If --include or --exclude (-I, -X, respectively) are given, the
  .gitattributes will be modified to include any new filepath patterns as given by
  those flags.
  
  If neither of those flags are given, the gitattributes will be incrementally
  modified to include new filepath extensions as they are rewritten in history.
  
Include and exclude
-------------------

You can configure Git LFS to only migrate tree entries whose pathspec matches
the include glob and does not match the exclude glob, to reduce total migration
time or to only migrate part of your repo. Specify multiple patterns using the
comma as the delimiter.

Pattern matching is done as given to be functionally equivalent to pattern
matching as in .gitattributes.

Include and exclude 
--------------------

You can configure Git LFS to only migrate commits reachable by references
include by --include-ref and not reachable by --exclude-ref.

        D---E---F
       /         \
  A---B------C    refs/heads/my-feature
   \          \
    \          refs/heads/master
     \
      refs/remotes/origin/master

In the above configuration, the following commits are reachable by each ref:

refs/heads/master:         C, B, A
refs/heads/my-feature:     F, E, D, B, A
refs/remote/origin/master: A

The following configuration:

  --include-ref=refs/heads/my-feature
  --include-ref=refs/heads/master
  --exclude-ref=refs/remotes/origin/master

Would, therefore, include commits: F, E, D, C, B, but exclude commit A.

The presence of flag --everything indicates that all local references should be
migrated.

Examples
--------

Migrate unpushed commits
------------------------

The migrate command's most common use case is to convert large git objects to
LFS before pushing your commits. By default, it only scans commits that don't
exist on any remote, so long as the repository is non-bare.

First, run git lfs migrate info to list the file types taking up the most
space in your repository.


$ git lfs migrate info
migrate: Fetching remote refs: ..., done
migrate: Sorting commits: ..., done
migrate: Examining commits: 100% (1/1), done
*.mp3  	284 MB	  1/1 files(s)	100%
*.pdf  	42 MB 	  8/8 files(s)	100%
*.psd  	9.8 MB	15/15 files(s)	100%
*.ipynb	6.9 MB	  6/6 files(s)	100%
*.csv  	5.8 MB	  2/2 files(s)	100%
  
  
  Now, you can run git lfs migrate import to convert some file types to LFS:
  
  
  $ git lfs migrate import --include="*.mp3,*.psd"
  migrate: Fetching remote refs: ..., done
  migrate: Sorting commits: ..., done
  migrate: Rewriting commits: 100% (1/1), done
  master	d2b959babd099fe70da1c1512e2475e8a24de163 -> 136e706bf1ae79643915c134e17a6c933fd53c61
  migrate: Updating refs: ..., done
  
  
Migrate local history
---------------------

You can also migrate the entire history of your repository:


# Check for large files in your local master branch
$ git lfs migrate info --include-ref=master

# Check for large files in every branch
$ git lfs migrate info --everything


The same flags will work in import mode:


# Convert all zip files in your master branch
$ git lfs migrate import --include-ref=master --include="*.zip"

# Convert all zip files in every local branch
$ git lfs migrate import --everything --include="*.zip"


Note: This will require a force push to any existing Git remotes.

`
ManPages["pointer"] = `
git lfs pointer --file=path/to/file
git lfs pointer --file=path/to/file --pointer=path/to/pointer
git lfs pointer --file=path/to/file --stdin

Builds and optionally compares generated pointer files to ensure consistency
between different Git LFS implementations.

Options:

* --file:
    A local file to build the pointer from.
  
* --pointer:
    A local file including the contents of a pointer generated from another
    implementation.  This is compared to the pointer generated from --file.
  
* --stdin:
    Reads the pointer from STDIN to compare with the pointer generated from
    --file.
  
`
ManPages["post-checkout"] = `
git lfs post-checkout <rev_before> <ref_after> <is_branch_checkout>

Responds to Git post-checkout events. It makes sure that any files which are
marked as lockable by git lfs track are read-only in the working copy, if
not currently locked by the local user.

`
ManPages["post-commit"] = `
git lfs post-commit

Responds to Git post-commit events. It makes sure that any files which are
marked as lockable by git lfs track are read-only in the working copy, if
not currently locked by the local user.

Where the git lfs post-merge command, which has a similar purpose, must
examine all files in the working copy, git lfs post-commit can limit
itself checking only those files which have changed in HEAD.  It primarily
handles newly added lockable files which have not yet been made read-only.

`
ManPages["post-merge"] = `
git lfs post-merge <is_squash>

Responds to Git post-merge events. It makes sure that any files which are
marked as lockable by git lfs track are read-only in the working copy, if
not currently locked by the local user.

`
ManPages["pre-push"] = `
git lfs pre-push <remote> [remoteurl]

Responds to Git pre-hook events. It reads the range of commits from STDIN, in
the following format:

    <local-ref> SP <local-sha1> SP <remote-ref> SP <remote-sha1> \n

It also takes the remote name and URL as arguments.

`
ManPages["prune"] = `
git lfs prune [options]

Deletes local copies of LFS files which are old, thus freeing up disk space.
Prune operates by enumerating all the locally stored objects, and then deleting
any which are not referenced by at least ONE of the following:

* the current checkout
* a 'recent branch'; see "Recent files"
* a 'recent commit' on the current branch or recent branches; see "Recent files"
* a commit which has not been pushed; see "Unpushed lfs files"
* any other worktree checkouts; see git  worktree
  
  In general terms, prune will delete files you're not currently using and which
  are not 'recent', so long as they've been pushed i.e. the local copy is not the
  only one.
  
  The reflog is not considered, only commits. Therefore LFS objects that are
  only referenced by orphaned commits are always deleted.
  
  Note: you should not run git lfs prune if you have different repositories
  sharing the same custom storage directory; see git lfs config for more
  details about lfs.storage option.
  
Options:

* --dry-run -d
  Don't actually delete anything, just report on what would have been done
  
* --verify-remote -c
  Contact the remote and check that copies of the files we would delete
  definitely exist before deleting. See "Verify remote".
  
* --no-verify-remote
  Disables remote verification if lfs.pruneverifyremotealways was enabled in
  settings. See "Verify remote".
  
* --verbose -v
  Report the full detail of what is/would be deleted.
  
Recent files
------------

Prune won't delete LFS files referenced by 'recent' commits, in case you want
to use them again without having to download. The definition of 'recent' is
derived from the one used by git lfs fetch to download recent objects with
the --recent option, with an offset of a number of days (default 3) to ensure
that we always keep files you download for a few days.

Here are the git  config settings that control this behaviour:

* lfs.pruneoffsetdays 
  The number of extra days added to the fetch recent settings when using them
  to decide when to prune. So for a reference to be considered old enough to
  prune, it has to be this many days older than the oldest reference that would
  be downloaded via git lfs fetch --recent. Only used if the relevant
  fetch recent 'days' setting is non-zero. Default 3 days.
  
* lfs.fetchrecentrefsdays 
  lfs.fetchrecentremoterefs 
  lfs.fetchrecentcommitsdays 
  These have the same meaning as git lfs fetch with the --recent option,
  they are used as a base for the offset above. Anything which falls outside
  of this offsetted window is considered old enough to prune. If a day value is
  zero, that condition is not used at all to retain objects and they will be
  pruned.
  
Unpushed lfs files
------------------

When the only copy of an LFS file is local, and it is still reachable from any
reference, that file can never be pruned, regardless of how old it is.

To determine whether an LFS file has been pushed, we check the difference
between local refs and remote refs; where the local ref is ahead, any LFS files
referenced in those commits is unpushed and will not be deleted. This works
because the LFS pre-push hook always ensures that LFS files are pushed before
the remote branch is updated.

See "Default remote", for which remote is considered 'pushed' for pruning
purposes.

Verify remote
-------------

The --verify-remote option calls the remote to ensure that any LFS files to be
deleted have copies on the remote before actually deleting them.

Usually the check performed by "Unpushed lfs files" is enough to determine that
files have been pushed, but if you want to be extra sure at the expense of extra
overhead you can make prune actually call the remote API and verify the
presence of the files you're about to delete locally. See "Default remote" for
which remote is checked.

You can make this behaviour the default by setting lfs.pruneverifyremotealways
to true.

In addition to the overhead of calling the remote, using this option also
requires prune to distinguish between totally unreachable files (e.g. those that
were added to the index but never committed, or referenced only by orphaned
commits), and files which are still referenced, but by commits which are
prunable. This makes the prune process take longer.

Default remote
--------------

When identifying "Unpushed lfs files" and performing "Verify remote", a single
remote, 'origin', is normally used as the reference.  This one remote is
considered canonical; even if you use multiple remotes, you probably want to
retain your local copies until they've made it to that remote. 'origin' is used
by default because that will usually be a master central repo, or your fork of
it - in both cases that's a valid remote backup of your work. If origin doesn't
exist then by default nothing will be pruned because everything is treated as
'unpushed'.

You can alter the remote via git config: lfs.pruneremotetocheck. Set this
to a different remote name to check that one instead of 'origin'.

`
ManPages["pull"] = `
git lfs pull [options] [<remote>]

Download Git LFS objects for the currently checked out ref, and update
the working copy with the downloaded content if required.

This is equivalent to running the following 2 commands:

git lfs fetch [options] [<remote>]
git lfs checkout

Options:

* -I <paths> --include=<paths>:
  Specify lfs.fetchinclude just for this invocation; see [INCLUSION & EXCLUSION]
  
* -X <paths> --exclude=<paths>:
  Specify lfs.fetchexclude just for this invocation; see [INCLUSION & EXCLUSION]
  
Inclusion 
----------

You can configure Git LFS to only fetch objects to satisfy references in certain
paths of the repo, and/or to exclude certain paths of the repo, to reduce the
time you spend downloading things you do not use.

In gitconfig, set lfs.fetchinclude and lfs.fetchexclude to comma-separated lists
of paths to include/exclude in the fetch (wildcard matching as per gitignore).
Only paths which are matched by fetchinclude and not matched by fetchexclude
will have objects fetched for them.

Default remote
--------------

Without arguments, pull downloads from the default remote. The default remote is
the same as for git pull, i.e. based on the remote branch you're tracking
first, or origin otherwise.

`
ManPages["push"] = `
git lfs push [options] <remote> [<ref>...]
git lfs push <remote> [<ref>...]
git lfs push --object-id <remote> [<oid>...]

Upload Git LFS files to the configured endpoint for the current Git remote.  By
default, it filters out objects that are already referenced by the local clone
of the remote.

Options:

* --dry-run:
    Print the files that would be pushed, without actually pushing them.
  
* --all:
    This pushes all objects to the remote that are referenced by any commit
    reachable from the refs provided as arguments. If no refs are provided, then
    all refs are pushed.
  
* --object-id:
    This pushes only the object OIDs listed at the end of the command, separated
    by spaces.
  
`
ManPages["smudge"] = `
git lfs smudge [<path>]
git lfs smudge --skip [<path>]

Read a Git LFS pointer file from standard input and write the contents
of the corresponding large file to standard output.  If needed,
download the file's contents from the Git LFS endpoint.  The <path>
argument, if provided, is only used for a progress bar.

Smudge is typically run by Git's smudge filter, configured by the repository's
Git attributes.

Options:

Without any options, git lfs smudge outputs the raw Git LFS content to
standard output.

* --skip:
    Skip automatic downloading of objects on clone or pull.
  
Known bugs
----------

On Windows, Git does not handle files in the working tree larger than 4
gigabytes.

For more information, see: https://github.com/git-lfs/git-lfs/issues/2434.

`
ManPages["standalone-file"] = `
git lfs standalone-file

Provides a standalone transfer adapter for file URLs (local paths).

By default, Git LFS requires the support of an HTTP server to implement the Git
LFS protocol. However, this tool allows the use of URLs starting with file:///
(that is, those representing local paths) in addition. Configuration is not
necessary; Git LFS handles this internally.

When invoked, this tool speaks JSON on input and output as a standalone transfer
adapter. It is not intended for use by end users.

`
ManPages["status"] = `
git lfs status [<options>]

Display paths of Git LFS objects that

* have not been pushed to the Git LFS server.  These are large files
  that would be uploaded by git push.
  
* have differences between the index file and the current HEAD commit.
  These are large files that would be committed by git commit.
  
* have differences between the working tree and the index file.  These
  are files that could be staged using git add.
  
Options:

* --porcelain:
    Give the output in an easy-to-parse format for scripts.
* --json:
    Give the output in a stable json format for scripts.
  
`
ManPages["track"] = `
git lfs track [options] [<pattern>...]

Start tracking the given patterns(s) through Git LFS.  The <pattern> argument
is written to .gitattributes. If no paths are provided, simply list the
currently-tracked paths.

The [gitattributes documentation](https://git-scm.com/docs/gitattributes) states
that patterns use the [gitignore pattern rules](https://git-scm.com/docs/gitignore)
to match paths.

Options:

* --verbose -v:
  If enabled, have git lfs track log files which it will touch. Disabled by
  default.
  
* --dry-run -d:
  If enabled, have git lfs track log all actions it would normally take
  (adding entries to .gitattributes, touching files on disk, etc) without
  performing any mutative operations to the disk.
  
  git lfs track --dry-run [files] also implicitly mocks the behavior of
  passing the --verbose, and will log in greater detail what it is doing.
  
  Disabled by default.
  
* --lockable -l
  Make the paths 'lockable', meaning they should be locked to edit them, and
  will be made read-only in the working copy when not locked.
  
* --not-lockable
  Remove the lockable flag from the paths so they are no longer read-only unless
  locked.
  
* --no-modify-attrs
  Makes matched entries stat-dirty so that Git can re-index files you wish to
  convert to LFS. Does not modify any .gitattributes file(s).
  
Examples
--------

* List the patterns that Git LFS is currently tracking:
  
    git lfs track
  
* Configure Git LFS to track GIF files:
  
    git lfs track "*.gif"
  
* Configure Git LFS to track PSD files and make them read-only unless locked:
  
    git lfs track --lockable "*.psd"
  
`
ManPages["uninstall"] = `
git lfs uninstall

Perform the following actions to remove the Git LFS configuration:

* Remove the "lfs" clean and smudge filters from the global Git config.
* Uninstall the Git LFS pre-push hook if run from inside a Git repository.
  
Options:

* --local:
    Removes the "lfs" smudge and clean filters from the local repository's git
    config, instead of the global git config (~/.gitconfig).
  
`
ManPages["unlock"] = `
git lfs unlock "Options" <path>

Removes the given file path as "locked" on the Git LFS server. Files must exist
and have a clean git status before they can be unlocked. The --force flag will
skip these checks.

Options:

* -r <name> --remote=<name>:
  Specify the Git LFS server to use. Ignored if the lfs.url config key is set.
  
* -f --force:
  Tells the server to remove the lock, even if it's owned by another user.
  
* -i <id> --id=<id>:
  Specifies a lock by its ID instead of path.
  
* --json:
  Writes lock info as JSON to STDOUT if the command exits successfully. Intended
  for interoperation with external tools. If the command returns with a non-zero
  exit code, plain text messages will be sent to STDERR.
  
`
ManPages["untrack"] = `
git lfs untrack <path>...

Stop tracking the given path(s) through Git LFS.  The <path> argument
can be a glob pattern or a file path.

Examples
--------

* Configure Git LFS to stop tracking GIF files:
  
    git lfs untrack "*.gif"
  
`
ManPages["update"] = `
git lfs update [--manual | --force]

Updates the Git hooks used by Git LFS. Silently upgrades known hook contents.
If you have your own custom hooks you may need to use one of the extended
options below.

Options:

* --manual -m
    Print instructions for manually updating your hooks to include git-lfs 
    functionality. Use this option if git lfs update fails because of existing
    hooks and you want to retain their functionality.
  
* --force -f
    Forcibly overwrite any existing hooks with git-lfs hooks. Use this option
    if git lfs update fails because of existing hooks but you don't care
    about their current contents.
  
`
ManPages["git-lfs"] = `
git lfs <command> [<args>]

Git LFS is a system for managing and versioning large files in
association with a Git repository.  Instead of storing the large files
within the Git repository as blobs, Git LFS stores special "pointer
files" in the repository, while storing the actual file contents on a
Git LFS server.  The contents of the large file are downloaded
automatically when needed, for example when a Git branch containing
the large file is checked out.

Git LFS works by using a "smudge" filter to look up the large file
contents based on the pointer file, and a "clean" filter to create a
new version of the pointer file when the large file's contents change.
It also uses a pre-push hook to upload the large file contents to
the Git LFS server whenever a commit containing a new large file
version is about to be pushed to the corresponding Git server.

Commands
--------

Like Git, Git LFS commands are separated into high level ("porcelain")
commands and low level ("plumbing") commands.

High level commands 
--------------------

* git lfs env:
    Display the Git LFS environment.
* git lfs checkout:
    Populate working copy with real content from Git LFS files.
* git lfs clone:
    Efficiently clone a Git LFS-enabled repository.
* git lfs fetch:
    Download Git LFS files from a remote.
* git lfs fsck:
    Check Git LFS files for consistency.
* git lfs install:
    Install Git LFS configuration.
* git lfs lock:
    Set a file as "locked" on the Git LFS server.
* git lfs locks:
    List currently "locked" files from the Git LFS server.
* git lfs logs:
    Show errors from the git-lfs command.
* git lfs ls-files:
    Show information about Git LFS files in the index and working tree.
* git lfs migrate:
    Migrate history to or from git-lfs
* git lfs prune:
    Delete old Git LFS files from local storage
* git lfs pull:
    Fetch LFS changes from the remote & checkout any required working tree files.
* git lfs push:
    Push queued large files to the Git LFS endpoint.
* git lfs status:
    Show the status of Git LFS files in the working tree.
* git lfs track:
    View or add Git LFS paths to Git attributes.
* git lfs uninstall:
    Uninstall Git LFS by removing hooks and smudge/clean filter configuration.
* git lfs unlock:
    Remove "locked" setting for a file on the Git LFS server.
* git lfs untrack:
    Remove Git LFS paths from Git Attributes.
* git lfs update:
    Update Git hooks for the current Git repository.
* git lfs version:
    Report the version number.
  
Low level commands 
-------------------

* git lfs clean:
    Git clean filter that converts large files to pointers.
* git lfs pointer:
    Build and compare pointers.
* git lfs pre-push:
    Git pre-push hook implementation.
* git lfs smudge:
    Git smudge filter that converts pointer in blobs to the actual content.
`
}
